# Copyright (c) 2024 Red Hat, Inc.
#
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from __future__ import absolute_import

import sys

from tobiko.cmd import _http_ping
from tobiko.cmd import _ping
from tobiko.cmd import _main

main = _main.main
TobikoHttpPing = _http_ping.TobikoHttpPing
TobikoPing = _ping.TobikoPing

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
